@@ -1956,7 +1956,7 @@ sub compute_flags {
 		    }
 		}
 	};
-	$urpm->{debug_URPM}("reg ex problem: " . $@) if $@;
+	$urpm->{error}("reg ex problem: " . $@) if $@;
     }
 }
 
